==> components-1.2.10.tgz: package/es/v1/Typography/props/propTypes.js <==
import PropTypes from 'prop-types';
export const propTypes = {
  children: PropTypes.node,
  $ui_className: PropTypes.string,
  $ui_tagName: PropTypes.string,
  $ui_isReset: PropTypes.bool,
  $ui_isDotted: PropTypes.bool,
  $ui_display: PropTypes.oneOf(['block', 'inlineBlock', 'inline', 'initial']),
  $ui_variant: PropTypes.oneOf(['regular', 'light', 'semibold', 'bold']),
  $ui_textAlign: PropTypes.oneOf(['left', 'right', 'center', 'justify']),
  $ui_transform: PropTypes.oneOf(['default', 'upper', 'lower', 'capital']),
  $ui_lineClamp: PropTypes.oneOf(['1', '2', '3', '4', '5']),
  $ui_typeFace: PropTypes.oneOf(['normal', 'italic']),
  $ui_decoration: PropTypes.oneOf(['default', 'underline', 'strike', 'overline']),
  $ui_size: PropTypes.oneOf(['7', '8', '9', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '24', '25', '26', '28', '29', '30', '32', '34', '35', '36', '40', '50', 'inherit']),
  $ui_lineHeight: PropTypes.oneOf(['0', '1', '8', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '24', '25', '26', '27', '28', '29', '30', '32', '33', '34', '35', '36', '38', '40', '41', '42', '45', '50', '52', '54', '55', '60', '70', '75', '120', 'inherit']),
  $ui_letterSpacing: PropTypes.oneOf(['0.1', '0.2', '0.3', '0.4', '0.5', '0.6', '0.7', '0.8', '0.9', '1', '2', '4', 'inherit']),
  $i18n_dataTitle: PropTypes.string,
  testId: PropTypes.string,
  customId: PropTypes.string,
  customStyle: PropTypes.object,
  a11yAttributes: PropTypes.object,
  tagAttributes: PropTypes.object
};

==> components-1.2.13.tgz: package/es/v1/Typography/props/propTypes.js <==
import PropTypes from 'prop-types';
export const propTypes = {
  children: PropTypes.node,
  $ui_className: PropTypes.string,
  $ui_tagName: PropTypes.string,
  $flag_reset: PropTypes.bool,
  $flag_dotted: PropTypes.bool,
  $ui_display: PropTypes.oneOf(['block', 'inlineBlock', 'inline', 'initial']),
  $ui_weight: PropTypes.oneOf(['regular', 'light', 'semibold', 'bold']),
  $ui_textAlign: PropTypes.oneOf(['left', 'right', 'center', 'justify']),
  $ui_transform: PropTypes.oneOf(['default', 'upper', 'lower', 'capital']),
  $ui_lineClamp: PropTypes.oneOf(['1', '2', '3', '4', '5']),
  $ui_typeFace: PropTypes.oneOf(['normal', 'italic']),
  $ui_decoration: PropTypes.oneOf(['default', 'underline', 'strike', 'overline']),
  $ui_size: PropTypes.oneOf(['7', '8', '9', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '24', '25', '26', '28', '29', '30', '32', '34', '35', '36', '40', '50', 'inherit']),
  $ui_lineHeight: PropTypes.oneOf(['0', '1', '8', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '24', '25', '26', '27', '28', '29', '30', '32', '33', '34', '35', '36', '38', '40', '41', '42', '45', '50', '52', '54', '55', '60', '70', '75', '120', 'inherit']),
  $ui_letterSpacing: PropTypes.oneOf(['0.1', '0.2', '0.3', '0.4', '0.5', '0.6', '0.7', '0.8', '0.9', '1', '2', '4', 'inherit']),
  $ui_wordBreak: PropTypes.oneOf(['breakAll', 'keepAll', 'breakWord']),
  $ui_wordWrap: PropTypes.oneOf(['normal', 'break']),
  $ui_whiteSpace: PropTypes.oneOf(['normal', 'noWrap', 'pre', 'preLine', 'preWrap']),
  $i18n_dataTitle: PropTypes.string,
  testId: PropTypes.string,
  customId: PropTypes.string,
  customStyle: PropTypes.object,
  $a11yAttributes_text: PropTypes.object,
  $tagAttributes_text: PropTypes.object
};
